@@ -3,7 +3,7 @@ use {
     crate::{
         app::{AppContext, LineNumber},
         command::{ScrollCommand, move_sel},
-        display::{CropWriter, Screen, SPACE_FILLING, W},
+        display::{Screen, W},
         errors::*,
         pattern::{InputPattern, NameMatch},
         skin::PanelSkin,
@@ -23,7 +23,7 @@ use {
         str,
     },
     syntect::highlighting::Style,
-    termimad::Area,
+    termimad::{Area, CropWriter, SPACE_FILLING},
 };
 
 /// a homogeneously colored piece of a line
@@ -104,6 +104,14 @@ impl SyntacticView {
         con: &AppContext,
     ) -> Result<bool, ProgramError> {
         let f = File::open(&self.path)?;
+        {
+            // if we detect the file isn't mappable, we'll
+            // let the ZeroLenFilePreview try to read it
+            let mmap = unsafe { Mmap::map(&f) };
+            if mmap.is_err() {
+                return Err(ProgramError::UnmappableFile);
+            }
+        }
         let md = f.metadata()?;
         if md.len() == 0 {
             return Err(ProgramError::ZeroLenFile);
@@ -130,6 +138,12 @@ impl SyntacticView {
             while line.ends_with('\n') || line.ends_with('\r') {
                 line.pop();
             }
+            for c in line.chars() {
+                if !is_char_printable(c) {
+                    debug!("unprintable char: {:?}", c);
+                    return Err(ProgramError::UnprintableFile);
+                }
+            }
             if pattern.is_empty() || pattern.score_of_string(&line).is_some() {
                 let name_match = pattern.search_string(&line);
                 let regions = if let Some(highlighter) = highlighter.as_mut() {
@@ -165,7 +179,9 @@ impl SyntacticView {
     }
 
     fn ensure_selection_is_visible(&mut self) {
-        if let Some(idx) = self.selection_idx {
+        if self.page_height >= self.lines.len() {
+            self.scroll = 0;
+        } else if let Some(idx) = self.selection_idx {
             let padding = self.padding();
             if idx < self.scroll + padding || idx + padding > self.scroll + self.page_height {
                 if idx <= padding {
@@ -259,7 +275,15 @@ impl SyntacticView {
         let old_scroll = self.scroll;
         self.scroll = cmd.apply(self.scroll, self.lines.len(), self.page_height);
         if let Some(idx) = self.selection_idx {
-            if self.scroll != old_scroll && idx >= old_scroll && idx < old_scroll + self.page_height {
+            if self.scroll == old_scroll {
+                let old_selection = self.selection_idx;
+                if cmd.is_up() {
+                    self.selection_idx = Some(0);
+                } else {
+                    self.selection_idx = Some(self.lines.len() - 1);
+                }
+                return self.selection_idx == old_selection;
+            } else  if idx >= old_scroll && idx < old_scroll + self.page_height {
                 if idx + self.scroll < old_scroll {
                     self.selection_idx = Some(0);
                 } else if idx + self.scroll - old_scroll >= self.lines.len() {
@@ -298,7 +322,7 @@ impl SyntacticView {
             .unwrap_or(Color::AnsiValue(240));
         let match_bg = styles.preview_match.get_bg().unwrap_or(Color::AnsiValue(28));
         let code_width = area.width as usize - 1; // 1 char left for scrollbar
-        let scrollbar = area.scrollbar(self.scroll as i32, self.lines.len() as i32);
+        let scrollbar = area.scrollbar(self.scroll, self.lines.len());
         let scrollbar_fg = styles.scrollbar_thumb.get_fg()
             .or_else(|| styles.preview.get_fg())
             .unwrap_or(Color::White);
@@ -427,3 +451,9 @@ fn is_thumb(y: usize, scrollbar: Option<(u16, u16)>) -> bool {
     })
 }
 
+/// tell whether the character is normal enough to be displayed by the
+/// syntactic view (if not we'll use a hex view)
+fn is_char_printable(c: char) -> bool {
+    // the tab is printable because it's replaced by spaces
+    c == '\t' || !c.is_control()
+}
